==> Pyrogram-1.0.4-py3-none-any.whl: pyrogram/raw/types/message_action_chat_create.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class MessageActionChatCreate(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~pyrogram.raw.base.MessageAction`.

    Details:
        - Layer: ``117``
        - ID: ``0xa6638b9a``

    Parameters:
        title: ``str``
        users: List of ``int`` ``32-bit``
    """

    __slots__: List[str] = ["title", "users"]

    ID = 0xa6638b9a
    QUALNAME = "pyrogram.raw.types.MessageActionChatCreate"

    def __init__(self, *, title: str, users: List[int]) -> None:
        self.title = title  # string
        self.users = users  # Vector<int>

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "MessageActionChatCreate":
        # No flags
        
        title = String.read(data)
        
        users = TLObject.read(data, Int)
        
        return MessageActionChatCreate(title=title, users=users)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        # No flags
        
        data.write(String(self.title))
        
        data.write(Vector(self.users, Int))
        
        return data.getvalue()

==> Pyrogram-1.0.7-py3-none-any.whl: pyrogram/raw/types/message_action_chat_create.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class MessageActionChatCreate(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~pyrogram.raw.base.MessageAction`.

    Details:
        - Layer: ``117``
        - ID: ``0xa6638b9a``

    Parameters:
        title: ``str``
        users: List of ``int`` ``32-bit``
    """

    __slots__: List[str] = ["title", "users"]

    ID = 0xa6638b9a
    QUALNAME = "types.MessageActionChatCreate"

    def __init__(self, *, title: str, users: List[int]) -> None:
        self.title = title  # string
        self.users = users  # Vector<int>

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "MessageActionChatCreate":
        # No flags
        
        title = String.read(data)
        
        users = TLObject.read(data, Int)
        
        return MessageActionChatCreate(title=title, users=users)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        # No flags
        
        data.write(String(self.title))
        
        data.write(Vector(self.users, Int))
        
        return data.getvalue()
